@@ -7,16 +7,15 @@ use Any::Moose;
 use Data::Dumper;
 use AnyEvent::Gearman;
 use AnyEvent::Gearman::Worker::RetryConnection;
+use UUID::Random;
 
+our $VERSION = '0.7'; # VERSION
 
-our $VERSION = '0.6'; # VERSION
-
-
-has 'pid' => (is => 'rw', isa => 'Str', default=>sub{return $$;});
 
 has 'job_servers' => (is => 'rw', isa => 'ArrayRef',required => 1);
 
-has 'prefix' => (is => 'rw', isa => 'Str', default=>'IPC::AnyEvent::Gearman#');
+
+has channel => (is => 'rw', default=>sub{UUID::Random::generate;} );
 
 has 'on_recv' => (is => 'rw', isa=>'CodeRef', 
     default=>sub{return sub{WARN 'You need to set on_recv function'};}
@@ -36,17 +35,9 @@ default=>sub{
 },
 );
 
-has 'worker' => (is=>'rw', isa=>'Object',
-                    );
+has 'worker' => (is=>'rw', isa=>'Object',);
 
-after 'pid' => sub{
-    my $self = shift;
-    if( @_ && $self->{listening}){
-        $self->_renew_connection();    
-    }
-};
-
-after 'prefix' => sub{
+after 'channel' => sub{
     my $self = shift;
     if( @_ && $self->{listening}){
         $self->_renew_connection();    
@@ -69,25 +60,18 @@ sub listen{
     $self->_renew_connection();
 }
 
-sub channel{
-    my $self = shift;
-    my $pid = shift;
-    $pid = $self->pid() unless( $pid );
-    return $self->prefix().$pid;
-}
-
 sub send{
     my $self = shift;
-    my $target_pid = shift;
+    my $target_channel= shift;
     my $data = shift;
     $self->client->add_task(
-        $self->channel($target_pid) => $data,
+        $target_channel => $data,
         on_complete => sub{
             my $result = $_[1];
-            $self->on_sent()->($self->channel($target_pid),$_[1]);
+            $self->on_sent()->($target_channel,$_[1]);
         },
         on_fail => sub{
-            $self->on_fail()->($self->channel($target_pid));
+            $self->on_fail()->($target_channel);
         }
     );
 }
@@ -99,7 +83,7 @@ sub _renew_connection{
     $worker = AnyEvent::Gearman::Worker::RetryConnection::patch_worker($worker);
     $self->worker( $worker );
     $self->worker->register_function(
-        $self->prefix().$self->pid() => sub{
+        $self->channel() => sub{
             my $job = shift;
             my $res = $self->on_recv()->($job->workload);
             $res = '' unless defined($res);
@@ -112,7 +96,8 @@ __PACKAGE__->meta->make_immutable;
 
 1;
 
-__END__
+
+
 =pod
 
 =head1 NAME
@@ -121,7 +106,7 @@ IPC::AnyEvent::Gearman - IPC through gearmand.
 
 =head1 VERSION
 
-version 0.6
+version 0.7
 
 =head1 SYNOPSIS
 
@@ -130,6 +115,7 @@ version 0.6
     
     #receive    
     my $recv = IPC::AnyEvent::Gearman->new(job_servers=>['localhost:9999']);
+    $recv->channel('BE_CALLED'); # channel is set with a random UUID by default 
     $recv->on_recv(sub{
         my $msg = shift;
         print "received msg : $data\n";
@@ -141,26 +127,21 @@ version 0.6
     $cv->recv;
 
     #send
+    my $ch = 'BE_CALLED';
     my $send = IPC::AnyEvent::Gearman->new(server=>['localhost:9999']);
-    $send->pid(1102);
-    my $result = $send->send("TEST DATA");
+    my $result = $send->send($ch,"TEST DATA");
+    pritn $result; # prints "OK"
 
 =head1 ATTRIBUTES
 
-=head2 pid
-
-'pid' is unique id for identifying each process.
-This can be any value not just PID.
-It is filled own PID by default.
-
 =head2 job_servers
 
-ArrayRef of hosts.
+ArrayRef of hosts. *REQUIRED*
 
-=head2 prefix
+=head2 channel
 
-When register function, it uses prefix+pid as function name.
-It is filled 'IPC::AnyEvent::Gearman#' by default. 
+get/set channel. When set, reconnect to new channel.
+It is set with Random-UUID by default.
 
 =head2 on_recv
 
@@ -184,17 +165,15 @@ First argument is a channel string.
 
 To receive message, you MUST call listen().
 
-=head2 channel
-
-get prefix+pid
+    my $sender = IPC::AnyEvent::Gearman->new(channel=>'ADMIN',job_servers=>['localhost:9998']);
+    $sender->listen();
 
 =head2 send
 
-To send data to process listening prefix+pid, use this.
+To send data to process listening channel, use this.
 
     my $sender = IPC::AnyEvent::Gearman->new(job_servers=>['localhost:9998']);
-    $sender->prefix('MYIPC');
-    $sender->send(1201,'DATA');
+    $sender->send($channel,'DATA');
 
 =head1 AUTHOR
 
@@ -209,3 +188,7 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
+
+__END__
+
+
